scoretemplatetools
==================

.. automodule:: abjad.tools.scoretemplatetools

.. only:: html

   Concrete classes
   ----------------

   .. autosummary::

      ~abjad.tools.scoretemplatetools.GroupedRhythmicStavesScoreTemplate.GroupedRhythmicStavesScoreTemplate.GroupedRhythmicStavesScoreTemplate
      ~abjad.tools.scoretemplatetools.GroupedStavesScoreTemplate.GroupedStavesScoreTemplate.GroupedStavesScoreTemplate
      ~abjad.tools.scoretemplatetools.StringOrchestraScoreTemplate.StringOrchestraScoreTemplate.StringOrchestraScoreTemplate
      ~abjad.tools.scoretemplatetools.StringQuartetScoreTemplate.StringQuartetScoreTemplate.StringQuartetScoreTemplate
      ~abjad.tools.scoretemplatetools.TwoStaffPianoScoreTemplate.TwoStaffPianoScoreTemplate.TwoStaffPianoScoreTemplate
